summary refs log tree commit diff
path: root/quantum/process_keycode
diff options
context:
space:
mode:
authorRyan <fauxpark@gmail.com>2022-10-22 01:46:10 +1100
committerGitHub <noreply@github.com>2022-10-21 15:46:10 +0100
commit7cbff9d921879ef3c54837cb2ffc455e019f45b4 (patch)
tree03e6555c188204115bafeedd65fb66a5fa03fc5a /quantum/process_keycode
parentb33fc349671148bff6f0a60172b53c51e59cda49 (diff)
Deprecate `KC_LOCK` for `QK_LOCK` (#18796)
Diffstat (limited to 'quantum/process_keycode')
-rw-r--r--quantum/process_keycode/process_key_lock.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/quantum/process_keycode/process_key_lock.c b/quantum/process_keycode/process_key_lock.c
index 941a2c5780..2542e32ec2 100644
--- a/quantum/process_keycode/process_key_lock.c
+++ b/quantum/process_keycode/process_key_lock.c
@@ -70,7 +70,7 @@ bool process_key_lock(uint16_t *keycode, keyrecord_t *record) {
     //    reset the state in our map and return false. When the user releases the
     //    key, the up event will no longer be masked and the OS will observe the
     //    released key.
     // 3. KC_LOCK was just pressed. In this case, we set up the state machine
     //    to watch for the next key down event, and finish processing
     // 4. The keycode is below 0xFF, and we are watching for new keys. In this case,
     //    we will send the key down event to the os, and set the key_state for that
@@ -95,20 +95,20 @@ bool process_key_lock(uint16_t *keycode, keyrecord_t *record) {
 
     if (record->event.pressed) {
         // Non-standard keycode, reset and return
-        if (!(IS_STANDARD_KEYCODE(translated_keycode) || translated_keycode == KC_LOCK)) {
+        if (!(IS_STANDARD_KEYCODE(translated_keycode) || translated_keycode == QK_LOCK)) {
             watching = false;
             return true;
         }
 
         // If we're already watching, turn off the watch.
-        if (translated_keycode == KC_LOCK) {
+        if (translated_keycode == QK_LOCK) {
             watching = !watching;
             return false;
         }
 
         if (IS_STANDARD_KEYCODE(translated_keycode)) {
             // We check watching first. This is so that in the following scenario, we continue to
             // hold the key: KC_LOCK, KC_F, KC_LOCK, KC_F
             // If we checked in reverse order, we'd end up holding the key pressed after the second
             // KC_F press is registered, when the user likely meant to hold F
             if (watching) {
@@ -70,7 +70,7 @@ bool process_key_lock(uint16_t *keycode, keyrecord_t *record) {
     //    key, the up event will no longer be masked and the OS will observe the
     //    released key.
-    // 3. KC_LOCK was just pressed. In this case, we set up the state machine
+    // 3. QK_LOCK was just pressed. In this case, we set up the state machine
     //    to watch for the next key down event, and finish processing
     // 4. The keycode is below 0xFF, and we are watching for new keys. In this case,
@@ -95,20 +95,20 @@ bool process_key_lock(uint16_t *keycode, keyrecord_t *record) {
         if (IS_STANDARD_KEYCODE(translated_keycode)) {
             // We check watching first. This is so that in the following scenario, we continue to
-            // hold the key: KC_LOCK, KC_F, KC_LOCK, KC_F
+            // hold the key: QK_LOCK, KC_F, QK_LOCK, KC_F
             // If we checked in reverse order, we'd end up holding the key pressed after the second
             // KC_F press is registered, when the user likely meant to hold F